Documentation
¶
Overview ¶
internal/errorpage/errorpage.go
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NotFound ¶
func NotFound(w http.ResponseWriter, host string, appName string, activeRoutes []string)
NotFound renders an HTML page when no route is registered for the host. SECURITY: All dynamic content is HTML-escaped to prevent XSS.
func UpstreamDown ¶
func UpstreamDown(w http.ResponseWriter, host string, upstream string)
UpstreamDown renders an HTML page when the upstream server is not responding. Includes auto-refresh so the page reloads when the dev server starts. SECURITY: All dynamic content is HTML-escaped to prevent XSS.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.